/* eslint-disable @typescript-eslint/no-explicit-any */
import Autocomplete from "@mui/material/Autocomplete";
import TextField from "@mui/material/TextField";
import React, { useState } from "react";
import Paper from "@mui/material/Paper";
import { PaperComponentOnLoad } from "./PaperComponentOnLoad";
import { RenderTemplate } from "./RenderTemplate";
// import "@emotion/core";
import { ConditionalWrapper } from "../utility/ConditionalWrapper";
import Grid from "@mui/material/Grid";
import IconButton from "@mui/material/IconButton";
import EditIcon from "@mui/icons-material/Edit";
import CloseIcon from "@mui/icons-material/Close";
import { nanoid } from "@reduxjs/toolkit";
import { AutocompleteType, InputAux } from "../NerdInput/NerdInputEnums";
import { INerdAutoComplete } from "./typings";
import "./NerdAutocomplete.scss";

export const NerdAutoComplete = ({
  itemID,
  value,
  fullWidth,
  onChange,
  onInputChange,
  inputValue,
  label,
  placeholder,
  options = [],
  variant = "standard",
  required = false,
  helperText,
  loading,
  autocompleteType = AutocompleteType.CUSTOMER,
  icon,
  spacing = 1,
  alignItems = "center",
  disabled = false,
  //inputSize = 6,
  autoCompleteOptionLabel = "",
  className,
  isEditable = false,
}: INerdAutoComplete): JSX.Element => {
  const [open, setOpen] = useState(false);

  // const sizeWithIcons = fullWidth ? 11 : inputSize;
  //const customInputSize = fullWidth && !icon ? 12 : sizeWithIcons;

  return (
    <ConditionalWrapper
      condition={icon !== undefined}
      wrapper={(childrenContent: JSX.Element) => (
        <Grid container spacing={spacing} alignItems={alignItems}>
          {childrenContent}
        </Grid>
      )}
    >
      <React.Fragment>
        {icon && <Grid item>{icon}</Grid>}
        <Grid item sm>
          <Autocomplete
            id={itemID}
            open={open}
            value={value}
            fullWidth={fullWidth}
            onOpen={() => setOpen(true)}
            onClose={() => setOpen(false)}
            onChange={onChange}
            onInputChange={onInputChange}
            inputValue={inputValue}
            options={options}
            clearIcon={null}
            getOptionLabel={(option: any) =>
              getOptionLabel(option, autoCompleteOptionLabel)
            }
            onKeyDown={(event) => {
              if (event.key === "Enter") {
                // Prevent's default 'Enter' behavior.
                event.preventDefault();
                // handler code
              }
            }}
            renderInput={(params: any) => (
              <TextField
                {...params}
                label={label}
                variant={variant}
                placeholder={placeholder}
                InputLabelProps={{
                  shrink: true,
                }}
                InputProps={{
                  ...params.InputProps,
                  endAdornment: null,
                }}
                helperText={renderHelperText(required, helperText)}
                required={required}
                fullWidth
              />
            )}
            renderOption={(
              props: React.HTMLAttributes<HTMLLIElement>,
              option: any
            ) => {
              return (
                <RenderTemplate
                  {...props}
                  option={option}
                  autocompleteType={autocompleteType}
                  optionsArray={options}
                />
              );
            }}
            PaperComponent={(props: any) => {
              if (!inputValue || loading) {
                return (
                  <PaperComponentOnLoad
                    {...{ props, inputValue, autocompleteType, loading }}
                    key={nanoid()}
                    className={className ? "autocompleteSmall" : ""}
                  />
                );
              }

              return (
                <Paper
                  {...props}
                  key={nanoid()}
                  className={className ? "autocompleteSmall" : ""}
                >
                  {props.children}
                </Paper>
              );
            }}
          />
        </Grid>
        {icon && (
          <Grid item flexDirection={"column"} display="flex">
            {isEditable && (
              <IconButton
                disabled={disabled}
                size="small"
                onClick={(event: React.SyntheticEvent<Element, Event>) => {
                  setOpen(false);
                  onChange(event, "");
                  onInputChange(event, "");
                }}
              >
                <EditIcon fontSize="small" />
              </IconButton>
            )}
            <IconButton
              disabled={disabled}
              size="small"
              onClick={(event: React.SyntheticEvent<Element, Event>) => {
                setOpen(false);
                onChange(event, "");
                onInputChange(event, "");
              }}
            >
              <CloseIcon fontSize="small" />
            </IconButton>
          </Grid>
        )}
      </React.Fragment>
    </ConditionalWrapper>
  );
};

/**
 *
 * @param required
 * @param helperText
 */
function renderHelperText(
  required: boolean,
  helperText: React.ReactNode
): string | React.ReactNode {
  if (!helperText) {
    return "";
  }
  return required ? InputAux.REQUIRED : helperText;
}

/**
 *
 * @param option
 * @param autoCompleteOptionLabel
 */
function getOptionLabel(option: any, autoCompleteOptionLabel?: string) {
  if (typeof option === "string") {
    return option;
  }

  if (typeof option === "object" && Object.keys(option).length > 0) {
    return option[autoCompleteOptionLabel as string];
  }

  return "";
}
