import CircularProgress from "@mui/material/CircularProgress";
import ClickAwayListener from "@mui/material/ClickAwayListener";
import Grid from "@mui/material/Grid";
import Paper from "@mui/material/Paper";
import React from "react";
import PersonSearchIcon from "@mui/icons-material/PersonSearch";
import { NerdHeading } from "../NerdHeading";
import MapTwoToneIcon from "@mui/icons-material/MapTwoTone";
import { Divider, Stack, Typography } from "@mui/material";
import "./NerdAutocomplete.scss";
import { uid } from "../utility/utils";
import {
  AutocompleteOnLoadHeading,
  AutocompleteType,
} from "../NerdInput/NerdInputEnums";
import { WrapperCustomerOnloadProps } from "./typings";

/**
 * @param { React.HTMLAttributes<HTMLElement> } paperProps - Autocomplete props onLoad
 * @returns { React.ReactElement } - Render react Autocomplete component onLoad
 */
export function PaperComponentOnLoad<Type>(
  paperProps: Type & {
    props: React.HTMLAttributes<HTMLElement>;
    inputValue: string;
    loading: boolean | undefined;
    autocompleteType?: AutocompleteType.CUSTOMER | AutocompleteType.ADDRESS;
    className?: string;
  }
): JSX.Element {
  const { className, inputValue, loading, autocompleteType, ...other } =
    paperProps;
  return (
    <Paper {...other} className={className ? "autocompleteSmall" : ""}>
      <ClickAwayListener onClickAway={() => console.log("onClick")}>
        <React.Fragment>
          {inputValue && loading ? (
            <WrapperCustomerOnload>
              <CircularProgress color="primary" size={40} />
              <NerdHeading text={"loading"} variant="h6" />
            </WrapperCustomerOnload>
          ) : (
            contentOnLoad(autocompleteType, inputValue, loading)
          )}
        </React.Fragment>
      </ClickAwayListener>
    </Paper>
  );
}

const CustomerOnload = () => {
  return (
    <WrapperCustomerOnload>
      <PersonSearchIcon fontSize="large" />
      <NerdHeading text={AutocompleteOnLoadHeading.CUSTOMER} variant="h6" />
    </WrapperCustomerOnload>
  );
};

const AdrressOnload = () => {
  return (
    <React.Fragment>
      <WrapperCustomerOnload>
        <MapTwoToneIcon fontSize="large" />
        <NerdHeading text={AutocompleteOnLoadHeading.ADDRESS} variant="h6" />
      </WrapperCustomerOnload>
      <Divider />
      <Grid container alignItems="center" justifyContent={"center"}>
        <Grid item py={1}>
          <Typography display={"block"} variant="caption" color="textSecondary">
            Powered by <b>Google</b> and <b>Archer</b>
          </Typography>
        </Grid>
      </Grid>
    </React.Fragment>
  );
};

const WrapperCustomerOnload = (
  props: WrapperCustomerOnloadProps
): JSX.Element => {
  return (
    <Stack
      direction="column"
      justifyContent="center"
      alignItems="center"
      spacing={2}
      py={7}
    >
      {props.children}
    </Stack>
  );
};

/**
 * @param {any} args - content onLoad args
 * @returns {void}
 */
function contentOnLoad(...args: unknown[]) {
  return args.map((arg, i): JSX.Element | undefined => {
    if (i === 0 && typeof arg === "string" && arg !== "") {
      switch (arg) {
        case AutocompleteType.CUSTOMER:
          return <CustomerOnload key={uid()} />;
        case AutocompleteType.ADDRESS:
          return <AdrressOnload key={uid()} />;
      }
    }
    return <React.Fragment key={uid()} />;
  });
}
