import Grid from "@mui/material/Grid";
import Pagination from "@mui/material/Pagination";
import React from "react";
import CustomArrow from "./CustomArrow";
import "../NerdPagination.scss";
import { useMediaQuery, useTheme } from "@mui/material";

const PageActions = (props: {
  page: number;
  selectPages: number[];
  onPageChange: (
    event: React.MouseEvent<HTMLButtonElement, MouseEvent>,
    page: number
  ) => void;
  disabledNext: boolean;
}): JSX.Element => {
  const { page, onPageChange, selectPages, disabledNext } = props;
  const pagesStored = [
    ...Array.from(new Set(selectPages.sort((a, b) => a - b))),
  ];
  const theme = useTheme();
  const matches = useMediaQuery(theme.breakpoints.down("sm"));

  return (
    <Grid
      container
      alignItems={"center"}
      className="paginationContainer"
      sx={{ marginLeft: "1rem" }}
    >
      <Grid item>
        <CustomArrow
          {...{
            onPageChange,
            page,
            disabledNext,
            pagesStored,
          }}
        >
          <Pagination
            count={pagesStored[pagesStored.length - 1]}
            defaultPage={page}
            siblingCount={matches ? 0 : 1}
            size={matches ? "small" : "medium"}
            hideNextButton={true}
            hidePrevButton={true}
            sx={{
              display: "inline",
              "&.MuiPagination-root *": {
                display: "inline",
              },
            }}
            onChange={(event, page) => {
              onPageChange(
                event as React.MouseEvent<HTMLButtonElement, MouseEvent>,
                page
              );
            }}
          />
        </CustomArrow>
      </Grid>
    </Grid>
  );
};

export default PageActions;
