import { TextField } from "@mui/material";
import { GridFilterInputValueProps } from "@mui/x-data-grid-pro";
import React from "react";

/**
 * DataGrid string filter input.
 *
 * @param {GridFilterInputValueProps} props Component props
 * @returns {React.ReactElement} TextField input for boolean type filter.
 */
export default function StringOperatorInput(
  props: GridFilterInputValueProps
): React.ReactElement {
  const { item, applyValue, focusElementRef } = props;

  const ref: React.Ref<HTMLDivElement> = React.useRef(null);
  React.useImperativeHandle(focusElementRef, () => ({
    focus: () => {
      (
        ref?.current?.querySelector(
          `input[value="${item.value || ""}"]`
        ) as HTMLElement
      )?.focus();
    },
  }));

  const handleFilterChange = (
    event: React.ChangeEvent<HTMLTextAreaElement | HTMLInputElement>
  ) => {
    applyValue({ ...item, value: event.target.value });
  };

  return (
    <TextField
      name="custom-filter-operator"
      placeholder="Value"
      label="Value"
      variant="standard"
      InputLabelProps={{
        shrink: true,
      }}
      value={item.value || ""}
      onChange={(e) => handleFilterChange(e)}
      ref={ref}
    />
  );
}
