import React from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import {
  findIconDefinition,
  IconDefinition,
  IconLookup,
  IconName,
  library,
} from "@fortawesome/fontawesome-svg-core";
import { fas } from "@fortawesome/free-solid-svg-icons";
import { IFontAwesomeSvgIconProps } from "./typings";

library.add(fas);

/**
 * This component is a wrapper for the FontAwesomeIcon component.
 * It is used to add icons to any library. More info here: https://fontawesome.com/v5/docs/web/use-with/react
 */

export const NerdIcon = (props: IFontAwesomeSvgIconProps) => {
  const {
    icon,
    severity,
    iconColor,
    size = "3x",
    onMouseEnter,
    onMouseLeave,
  } = props;

  if (!icon) {
    return null;
  }

  return (
    <span onMouseEnter={onMouseEnter} onMouseLeave={onMouseLeave}>
      {typeof icon === "string" ? (
        setCustomIconString({ ...{ icon, severity, iconColor, size } })
      ) : (
        <FontAwesomeIcon
          icon={icon}
          size={size}
          color={iconColor ?? "#0288d1"}
        />
      )}
    </span>
  );
};

/**
 *
 * @param root0
 * @param root0.icon
 * @param root0.iconColor
 * @param root0.severity
 * @param root0.size
 */
function setCustomIconString({
  icon,
  iconColor,
  severity,
  size = "3x",
}: IFontAwesomeSvgIconProps): JSX.Element {
  return (
    <FontAwesomeIcon
      icon={setCustomIconDefinition(icon as IconName)}
      color={
        iconColor && iconColor !== ""
          ? iconColor
          : colorSwitch(severity || "info")
      }
      size={size}
    />
  );
}

//TODO: fontawesome-svg-core package needs to be updated. (v5.15.4 current version). The icons name are were changed.
/**
 *
 * @param icon
 */
export function setCustomIconDefinition(icon: IconName): IconDefinition {
  const iconLookup: IconLookup = {
    prefix: "fas",
    iconName: icon,
  };
  const customIconDefinition: IconDefinition = findIconDefinition(iconLookup);

  return customIconDefinition;
}

/**
 *
 * @param color
 */
export function colorSwitch(color: string): string {
  switch (color) {
    case "error":
      return "#d32f2f";
    case "info":
      return "#0288d1";
    case "success":
      return "#2e7d32";
    case "warning":
      return "#ed6c02";
    default:
      return "#000";
  }
}
